@@ -49,22 +49,25 @@ status progStatus = {
 	"",				// my_email
 	true,			// bool sernbr_fname;
 	true,			// bool call_fname;
-	false,			// bool dt_fname;
+	1,				// int dt_fname;
+// 1: not used
+// 2: local time, append L
+// 3: local time, append time zone, i.e: CDT
+// 4: greenwich mean time, append Z
 	true,			// bool rgrnbr_fname;
 	true,			// bool arl_desc;
 	"1",			// string sernbr;
 	"1",			// string rgnbr
+	true,			// bool rri
 	false,			// bool insert_x;
 	RADIOGRAM,		// int tab;
 	"",
 	72,				// charcount
 	true,			// autowordwrap
-	"127.0.0.1",	// fldigi socket address
-	"7322",			// fldigi socket port
+	true,			// send_original
 	"127.0.0.1",	// fldigi xmlrpc socket address
 	"7362",			// fldigi xmlrpc socket port
 	false,			// use_compression
-	BASE64,			// encoder
 	0,				// selected_mode
 	0,				// index default_state
 	0,				// index default_county
@@ -74,8 +77,19 @@ status progStatus = {
 	"",				// swx_default_profile;
 	true,			// change_modem_with_autosend
 	false,			// sync_modem_to_fldigi
-	false,			// force_compression
-	false			// caplocal
+	false,			// caplocal
+	false,			// auto_open_url
+	5,				// retries;
+	60000,			// timeout;
+	5,				// exponent;
+	true,			// ID_on;
+	true,			// ID_off;
+	true,			// ID_restore;
+	false,			// arq_shown;
+	false,			// UI_expert;
+	false,			// UI_default;
+	0,				// int arq_notify_timeout
+	false			// bool notify_receipt
 };
 
 void status::saveLastState()
@@ -106,6 +120,7 @@ void status::saveLastState()
 	flmsgpref.set("myemail", my_email.c_str());
 	flmsgpref.set("sernbr", sernbr.c_str());
 	flmsgpref.set("rgnbr", rgnbr.c_str());
+	flmsgpref.set("rri", rri);
 	flmsgpref.set("sernbr_fname", sernbr_fname);
 	flmsgpref.set("rgnbr_fname", rgnbr_fname);
 	flmsgpref.set("arl_desc", arl_desc);
@@ -116,18 +131,20 @@ void status::saveLastState()
 
 	flmsgpref.set("charcount", charcount);
 	flmsgpref.set("autowordwrap", autowordwrap);
+	flmsgpref.set("send_original", send_original);
 
 	tab = selected_form;
 	flmsgpref.set("preset_tab", tab);
 
 	flmsgpref.set("mars_roster_file", mars_roster_file.c_str());
 
-	flmsgpref.set("socket_address", socket_addr.c_str());
-	flmsgpref.set("socket_port", socket_port.c_str());
+//	flmsgpref.set("socket_address", socket_addr.c_str());
+//	flmsgpref.set("socket_port", socket_port.c_str());
+
+	flmsgpref.set("xmlrpc_address", xmlrpc_addr.c_str());
+	flmsgpref.set("xmlrpc_port", xmlrpc_port.c_str());
 
 	flmsgpref.set("use_compression", use_compression);
-	flmsgpref.set("force_compression", force_compression);
-	flmsgpref.set("encoder", encoder);
 	flmsgpref.set("selected_mode", selected_mode);
 
 	flmsgpref.set("swx_index_default_state", swx_index_default_state);
@@ -141,6 +158,24 @@ void status::saveLastState()
 	flmsgpref.set("sync_modem_to_fldigi", sync_modem_to_fldigi);
 
 	flmsgpref.set("caplocal", caplocal);
+
+	flmsgpref.set("auto_open_url", auto_open_url);
+	flmsgpref.set("retries", retries);
+	flmsgpref.set("timeout", timeout);
+	flmsgpref.set("exponent", exponent);
+	flmsgpref.set("ID_on", ID_on);
+	flmsgpref.set("ID_off", ID_off);
+	flmsgpref.set("ID_restore", ID_restore);
+
+	arq_shown = arq_group->visible();
+
+	flmsgpref.set("arq_shown", arq_shown);
+
+	flmsgpref.set("UI_expert", UI_expert);
+	flmsgpref.set("UI_default", UI_default);
+
+	flmsgpref.set("arq_notify_timeout", arq_notify_timeout);
+	flmsgpref.set("notify_receipt", notify_receipt);
 }
 
 void status::loadLastState()
@@ -187,6 +222,8 @@ void status::loadLastState()
 			rgnbr = defbuffer;
 		free(defbuffer);
 
+		if (flmsgpref.get("rri", i, rri)) rri = i;
+
 		if (flmsgpref.get("sernbr_fname", i, i)) sernbr_fname = i;
 		if (flmsgpref.get("arl_desc", i, i)) arl_desc = i;
 		if (flmsgpref.get("rgnbr_fname", i, i)) rgnbr_fname = i;
@@ -198,6 +235,8 @@ void status::loadLastState()
 		flmsgpref.get("charcount", charcount, charcount);
 		if (flmsgpref.get("autowordwrap", i, autowordwrap)) autowordwrap = i;
 
+		if (flmsgpref.get("send_original", i, send_original)) send_original = i;
+
 		flmsgpref.get("preset_tab", tab, tab);
 
 		flmsgpref.get("mars_roster_file", defbuffer, "");
@@ -208,16 +247,12 @@ void status::loadLastState()
 			mars_roster_file.append("MARS_ROSTER.csv");
 		}
 
-		flmsgpref.get("socket_address", defbuffer, socket_addr.c_str());
-		socket_addr = defbuffer; free(defbuffer);
-
-		flmsgpref.get("socket_port", defbuffer, socket_port.c_str());
-		socket_port = defbuffer; free(defbuffer);
+		flmsgpref.get("xmlrpc_address", defbuffer, xmlrpc_addr.c_str());
+		xmlrpc_addr = defbuffer; free(defbuffer);
+		flmsgpref.get("xmlrpc_port", defbuffer, xmlrpc_port.c_str());
+		xmlrpc_port = defbuffer; free(defbuffer);
 
 		if (flmsgpref.get("use_compression", i, use_compression)) use_compression = i;
-		if (flmsgpref.get("force_compression", i, force_compression)) force_compression = i;
-
-		flmsgpref.get("encoder", encoder, encoder);
 
 		flmsgpref.get("selected_mode", selected_mode, selected_mode);
 
@@ -244,6 +279,43 @@ void status::loadLastState()
 
 		if (flmsgpref.get("caplocal", i, caplocal))
 			caplocal = i;
+
+		if (flmsgpref.get("auto_open_url", i, auto_open_url))
+			auto_open_url = i;
+
+		if (flmsgpref.get("retries", i, retries))
+			retries = i;
+
+		if (flmsgpref.get("timeout", i, timeout))
+			timeout = i;
+
+		if (flmsgpref.get("exponent", i, exponent))
+			exponent = i;
+
+		if (flmsgpref.get("ID_on", i, ID_on))
+			ID_on = i;
+
+		if (flmsgpref.get("ID_off", i, ID_off))
+			ID_off = i;
+
+		if (flmsgpref.get("ID_restore", i, ID_restore))
+			ID_restore = i;
+
+		if (flmsgpref.get("arq_shown", i, arq_shown))
+			arq_shown = i;
+
+		if (flmsgpref.get("UI_expert", i, UI_expert))
+			UI_expert = i;
+
+		if (flmsgpref.get("UI_default", i, UI_default))
+			UI_default = i;
+
+		if (flmsgpref.get("arq_notify_timeout", i, arq_notify_timeout))
+			arq_notify_timeout = i;
+
+		if (flmsgpref.get("notify_receipt", i, notify_receipt))
+			notify_receipt = i;
 	}
+
 }
 
